@@ -50,7 +50,8 @@ func (fc *File) Init(cacheFilePath string, persist bool) {
 }
 
 func (fc *File) Close() {
-	if !fc.persist || !fc.dirty {
+	if fc == nil || !fc.persist || !fc.dirty {
+		log.Debug("not persisting cache")
 		return
 	}
 
@@ -64,6 +65,11 @@ func (fc *File) Close() {
 // returns the value for the given key as long as
 // the duration is not expired
 func (fc *File) Get(key string) (string, bool) {
+	if fc == nil {
+		log.Debug("cache is nil, returning empty value for key:", key)
+		return "", false
+	}
+
 	val, found := fc.cache.Get(key)
 	if !found {
 		log.Debug("cache key not found:", key)
@@ -81,6 +87,11 @@ func (fc *File) Get(key string) (string, bool) {
 
 // sets the value for the given key with a duration
 func (fc *File) Set(key, value string, duration Duration) {
+	if fc == nil {
+		log.Debug("cache is nil, not setting value for key:", key)
+		return
+	}
+
 	seconds := duration.Seconds()
 
 	if seconds == 0 {
@@ -100,6 +111,11 @@ func (fc *File) Set(key, value string, duration Duration) {
 
 // delete the key from the cache
 func (fc *File) Delete(key string) {
+	if fc == nil {
+		log.Debug("cache is nil, not deleting key:", key)
+		return
+	}
+
 	log.Debug("deleting cache key:", key)
 	fc.cache.Delete(key)
 	fc.dirty = true
