@@ -3,8 +3,8 @@ package cli
 import (
 	"fmt"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/cli/image"
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
-	"github.com/jandedobbeleer/oh-my-posh/src/image"
 	"github.com/jandedobbeleer/oh-my-posh/src/prompt"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
@@ -51,7 +51,7 @@ Exports the config to an image file using customized output options.`,
 	Args: cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
 		configFile := config.Path(configFlag)
-		cfg := config.Load(configFile, shell.GENERIC, false)
+		cfg, _ := config.Load(configFile, shell.GENERIC, false)
 
 		flags := &runtime.Flags{
 			Config:        configFile,
