@@ -58,6 +58,7 @@ See the documentation to initialize your shell: https://ohmyposh.dev/docs/instal
 	initCmd.Flags().BoolVarP(&printOutput, "print", "p", false, "print the init script")
 	initCmd.Flags().BoolVarP(&strict, "strict", "s", false, "run in strict mode")
 	initCmd.Flags().BoolVar(&debug, "debug", false, "enable/disable debug mode")
+	initCmd.Flags().BoolVar(&eval, "eval", false, "output the prompt for eval")
 
 	_ = initCmd.MarkPersistentFlagRequired("config")
 
@@ -77,13 +78,13 @@ func runInit(sh string) {
 	cfg, hash := config.Load(configFile, sh, false)
 
 	flags := &runtime.Flags{
-		Shell:      sh,
-		Config:     configFile,
-		Strict:     strict,
-		Debug:      debug,
-		SaveCache:  true,
-		Init:       true,
-		ConfigHash: hash,
+		Shell:     sh,
+		Config:    configFile,
+		Strict:    strict,
+		Debug:     debug,
+		SaveCache: true,
+		Init:      true,
+		Eval:      eval,
 	}
 
 	env := &runtime.Terminal{}
@@ -97,6 +98,7 @@ func runInit(sh string) {
 	}()
 
 	feats := cfg.Features(env)
+	flags.ConfigHash = fmt.Sprintf("%s.%s", hash, feats.Hash())
 
 	var output string
 
