@@ -9,11 +9,11 @@ import (
 	"time"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/build"
+	"github.com/jandedobbeleer/oh-my-posh/src/cli/upgrade"
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
-	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 	"github.com/spf13/cobra"
 )
 
@@ -59,7 +59,7 @@ var upgradeCmd = &cobra.Command{
 		fmt.Print(terminal.StartProgress())
 
 		configFile := config.Path(configFlag)
-		cfg := config.Load(configFile, sh, false)
+		cfg, _ := config.Load(configFile, sh, false)
 		cfg.Upgrade.Cache = env.Cache()
 
 		defer func() {
@@ -84,18 +84,16 @@ var upgradeCmd = &cobra.Command{
 			fmt.Println(builder.String())
 		}()
 
-		latest, err := cfg.Upgrade.Latest()
+		latest, err := cfg.Upgrade.FetchLatest()
 		if err != nil {
 			log.Debug("failed to get latest version")
 			log.Error(err)
-			fmt.Printf("\n❌ %s\n\n", err)
+			fmt.Printf("\n  ❌ %s\n\n", err)
 
 			exitcode = 1
 			return
 		}
 
-		cfg.Upgrade.Version = fmt.Sprintf("v%s", latest)
-
 		if force {
 			log.Debug("forced upgrade")
 			exitcode = executeUpgrade(cfg.Upgrade)
@@ -104,7 +102,7 @@ var upgradeCmd = &cobra.Command{
 
 		if upgrade.IsMajorUpgrade(build.Version, latest) {
 			log.Debug("major upgrade available")
-			message := fmt.Sprintf("\n🚨 major upgrade available: v%s -> v%s, use oh-my-posh upgrade --force to upgrade\n\n", build.Version, latest)
+			message := fmt.Sprintf("\n  🚨 major upgrade available: v%s -> v%s, use oh-my-posh upgrade --force to upgrade\n\n", build.Version, latest)
 			fmt.Print(message)
 			return
 		}
