@@ -38,12 +38,12 @@ func (h *Haskell) Enabled() bool {
 
 	switch h.props.GetString(StackGhcMode, "never") {
 	case "always":
-		h.language.commands = []*cmd{stackGhcCmd}
+		h.commands = []*cmd{stackGhcCmd}
 		h.StackGhc = true
 	case "package":
-		_, err := h.language.env.HasParentFilePath("stack.yaml", false)
+		_, err := h.env.HasParentFilePath("stack.yaml", false)
 		if err == nil {
-			h.language.commands = []*cmd{stackGhcCmd}
+			h.commands = []*cmd{stackGhcCmd}
 			h.StackGhc = true
 		}
 	}
