@@ -7,7 +7,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/google/uuid"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/path"
@@ -46,7 +45,11 @@ func Init(env runtime.Environment, feats Features) string {
 	shell := env.Flags().Shell
 
 	switch shell {
-	case ELVISH:
+	case ELVISH, PWSH, PWSH5:
+		if shell != ELVISH && !env.Flags().Eval {
+			return PrintInit(env, feats, nil)
+		}
+
 		executable, err := getExecutablePath(env)
 		if err != nil {
 			return noExe
@@ -59,10 +62,18 @@ func Init(env runtime.Environment, feats Features) string {
 
 		config := quotePwshOrElvishStr(env.Flags().Config)
 		executable = quotePwshOrElvishStr(executable)
-		command := "eval ((external %s) init %s --config=%s --print%s | slurp)"
+
+		var command string
+
+		switch shell {
+		case PWSH, PWSH5:
+			command = "(@(& %s init %s --config=%s --print --eval%s) -join \"`n\") | Invoke-Expression"
+		case ELVISH:
+			command = "eval ((external %s) init %s --config=%s --print%s | slurp)"
+		}
 
 		return fmt.Sprintf(command, executable, shell, config, additionalParams)
-	case ZSH, BASH, FISH, CMD, XONSH, NU, PWSH, PWSH5:
+	case ZSH, BASH, FISH, CMD, XONSH, NU:
 		return PrintInit(env, feats, nil)
 	default:
 		return fmt.Sprintf(`echo "%s is not supported by Oh My Posh"`, shell)
@@ -83,7 +94,6 @@ func PrintInit(env runtime.Environment, features Features, startTime *time.Time)
 	}
 
 	configFile := env.Flags().Config
-	sessionID := uuid.NewString()
 	bashBLEsession = len(env.Getenv("BLE_SESSION_ID")) != 0
 
 	var script string
@@ -92,42 +102,34 @@ func PrintInit(env runtime.Environment, features Features, startTime *time.Time)
 	case PWSH, PWSH5:
 		executable = quotePwshOrElvishStr(executable)
 		configFile = quotePwshOrElvishStr(configFile)
-		sessionID = quotePwshOrElvishStr(sessionID)
 		script = pwshInit
 	case ZSH:
 		executable = QuotePosixStr(executable)
 		configFile = QuotePosixStr(configFile)
-		sessionID = QuotePosixStr(sessionID)
 		script = zshInit
 	case BASH:
 		executable = QuotePosixStr(executable)
 		configFile = QuotePosixStr(configFile)
-		sessionID = QuotePosixStr(sessionID)
 		script = bashInit
 	case FISH:
 		executable = quoteFishStr(executable)
 		configFile = quoteFishStr(configFile)
-		sessionID = quoteFishStr(sessionID)
 		script = fishInit
 	case CMD:
 		executable = escapeLuaStr(executable)
 		configFile = escapeLuaStr(configFile)
-		sessionID = escapeLuaStr(sessionID)
 		script = cmdInit
 	case NU:
 		executable = quoteNuStr(executable)
 		configFile = quoteNuStr(configFile)
-		sessionID = quoteNuStr(sessionID)
 		script = nuInit
 	case ELVISH:
 		executable = quotePwshOrElvishStr(executable)
 		configFile = quotePwshOrElvishStr(configFile)
-		sessionID = quotePwshOrElvishStr(sessionID)
 		script = elvishInit
 	case XONSH:
 		executable = quotePythonStr(executable)
 		configFile = quotePythonStr(configFile)
-		sessionID = quotePythonStr(sessionID)
 		script = xonshInit
 	default:
 		return fmt.Sprintf("echo \"No initialization script available for %s\"", shell)
@@ -137,11 +139,14 @@ func PrintInit(env runtime.Environment, features Features, startTime *time.Time)
 		"::OMP::", executable,
 		"::CONFIG::", configFile,
 		"::SHELL::", shell,
-		"::SESSION_ID::", sessionID,
 	).Replace(script)
 
 	shellScript := features.Lines(shell).String(init)
 
+	if env.Flags().Eval {
+		return shellScript
+	}
+
 	log.Debug(shellScript)
 
 	scriptPath, err := writeScript(env, shellScript)
@@ -149,13 +154,17 @@ func PrintInit(env runtime.Environment, features Features, startTime *time.Time)
 		return fmt.Sprintf("echo \"Failed to write init script: %s\"", err.Error())
 	}
 
-	if env.Flags().Debug {
-		script := sourceInit(env, shell, scriptPath, async)
-		log.Debug("init script:", script)
-		return printDebug(env, startTime)
+	sourceCommand := sourceInit(env, shell, scriptPath, async)
+
+	if !env.Flags().Debug {
+		return sourceCommand
 	}
 
-	return sourceInit(env, shell, scriptPath, async)
+	if len(sourceCommand) != 0 {
+		log.Debug("init source command:", sourceCommand)
+	}
+
+	return printDebug(env, startTime)
 }
 
 func printDebug(env runtime.Environment, startTime *time.Time) string {
@@ -179,6 +188,7 @@ func sourceInit(env runtime.Environment, shell, scriptPath string, async bool) s
 		var err error
 		scriptPath, err = env.RunCommand("cygpath", "-u", scriptPath)
 		if err != nil {
+			log.Error(err)
 			return fmt.Sprintf("echo \"Failed to convert Cygwin path due to %s\"", err.Error())
 		}
 	}
@@ -189,20 +199,17 @@ func sourceInit(env runtime.Environment, shell, scriptPath string, async bool) s
 
 	switch shell {
 	case PWSH, PWSH5:
-		return scriptPath
-	case ZSH:
-		return fmt.Sprintf("source '%s'", scriptPath)
-	case BASH:
-		return fmt.Sprintf("source '%s'", scriptPath)
-	case FISH:
-		return fmt.Sprintf("source %s", scriptPath)
-	case ELVISH:
-		return fmt.Sprintf("eval (slurp < %s)", scriptPath)
+		return fmt.Sprintf("& %s", quotePwshOrElvishStr(scriptPath))
+	case ZSH, BASH:
+		return fmt.Sprintf("source %s", QuotePosixStr(scriptPath))
 	case XONSH:
-		return fmt.Sprintf("source %s", scriptPath)
+		return fmt.Sprintf("source %s", quotePythonStr(scriptPath))
+	case FISH:
+		return fmt.Sprintf("source %s", quoteFishStr(scriptPath))
+	case ELVISH:
+		return fmt.Sprintf("eval (slurp < %s)", quotePwshOrElvishStr(scriptPath))
 	case CMD:
-		scriptPath = strings.ReplaceAll(scriptPath, `\`, `\\`)
-		return fmt.Sprintf(`load(io.open('%s', "r"):read("*a"))()`, scriptPath)
+		return fmt.Sprintf(`load(io.open('%s', "r"):read("*a"))()`, escapeLuaStr(scriptPath))
 	default:
 		return fmt.Sprintf("echo \"No source command available for %s\"", shell)
 	}
@@ -211,13 +218,14 @@ func sourceInit(env runtime.Environment, shell, scriptPath string, async bool) s
 func sourceInitAsync(shell, scriptPath string) string {
 	switch shell {
 	case PWSH, PWSH5:
-		return fmt.Sprintf(`function prompt() { %s }`, scriptPath)
+		return fmt.Sprintf("function prompt() { & %s }", quotePwshOrElvishStr(scriptPath))
 	case ZSH:
-		return fmt.Sprintf(`precmd() { source '%s' }`, scriptPath)
+		return fmt.Sprintf("precmd() { source %s }", QuotePosixStr(scriptPath))
 	case BASH:
-		return fmt.Sprintf(`PROMPT_COMMAND='source "%s"'`, scriptPath)
+		command := fmt.Sprintf("source %s", QuotePosixStr(scriptPath))
+		return fmt.Sprintf("PROMPT_COMMAND=%s", QuotePosixStr(command))
 	case FISH:
-		return fmt.Sprintf(`function fish_prompt; source %s; end`, scriptPath)
+		return fmt.Sprintf("function fish_prompt; source %s; end", quoteFishStr(scriptPath))
 	default:
 		return ""
 	}
